# swagger-client
No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:

```python
import server_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import server_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import server_client
from src.server_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth2
configuration = server_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = server_client.CollectionsApi(server_client.ApiClient(configuration))
collection_id = 'collection_id_example' # str | Identifier for an existing collection.
contract = server_client.AddScheduleContract() # AddScheduleContract | 

try:
    # Add a schedule to an existing collection.
    api_response = api_instance.collections_add_schedule_to_collection(collection_id, contract)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CollectionsApi->collections_add_schedule_to_collection: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/webapi/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CollectionsApi* | [**collections_add_schedule_to_collection**](docs/CollectionsApi.md#collections_add_schedule_to_collection) | **POST** /v3/collections/{collectionId}/schedules | Add a schedule to an existing collection.
*CollectionsApi* | [**collections_add_user_group_to_collection**](docs/CollectionsApi.md#collections_add_user_group_to_collection) | **POST** /v3/collections/{collectionId}/userGroups | Add a user group to an existing collection.
*CollectionsApi* | [**collections_add_user_to_collection**](docs/CollectionsApi.md#collections_add_user_to_collection) | **POST** /v3/collections/{collectionId}/users | Add a user to an existing collection.
*CollectionsApi* | [**collections_add_workflow_to_collection**](docs/CollectionsApi.md#collections_add_workflow_to_collection) | **POST** /v3/collections/{collectionId}/workflows | Add a workflow to an existing collection.
*CollectionsApi* | [**collections_create_collection**](docs/CollectionsApi.md#collections_create_collection) | **POST** /v3/collections | Create a new collection.
*CollectionsApi* | [**collections_delete_collection**](docs/CollectionsApi.md#collections_delete_collection) | **DELETE** /v3/collections/{collectionId} | Delete an existing collection.
*CollectionsApi* | [**collections_get_collection**](docs/CollectionsApi.md#collections_get_collection) | **GET** /v3/collections/{collectionId} | Retrieve details about an existing collection.
*CollectionsApi* | [**collections_get_collections**](docs/CollectionsApi.md#collections_get_collections) | **GET** /v3/collections | Retrieve all accessible collection records.
*CollectionsApi* | [**collections_remove_schedule_from_collection**](docs/CollectionsApi.md#collections_remove_schedule_from_collection) | **DELETE** /v3/collections/{collectionId}/schedules/{scheduleId} | Remove a schedule from an existing collection.
*CollectionsApi* | [**collections_remove_user_from_collection**](docs/CollectionsApi.md#collections_remove_user_from_collection) | **DELETE** /v3/collections/{collectionId}/users/{userId} | Remove a user from an existing collection.
*CollectionsApi* | [**collections_remove_user_group_from_collection**](docs/CollectionsApi.md#collections_remove_user_group_from_collection) | **DELETE** /v3/collections/{collectionId}/userGroups/{userGroupId} | Remove a user group from an existing collection.
*CollectionsApi* | [**collections_remove_workflow_from_collection**](docs/CollectionsApi.md#collections_remove_workflow_from_collection) | **DELETE** /v3/collections/{collectionId}/workflows/{workflowId} | Remove a workflow from an existing collection.
*CollectionsApi* | [**collections_update_collection**](docs/CollectionsApi.md#collections_update_collection) | **PUT** /v3/collections/{collectionId} | Update the name and/or owner of an existing collection.
*CollectionsApi* | [**collections_update_collection_user_group_permissions**](docs/CollectionsApi.md#collections_update_collection_user_group_permissions) | **PUT** /v3/collections/{collectionId}/userGroups/{userGroupId}/permissions | Update a user group&#39;s permissions within an existing collection.
*CollectionsApi* | [**collections_update_collection_user_permissions**](docs/CollectionsApi.md#collections_update_collection_user_permissions) | **PUT** /v3/collections/{collectionId}/users/{userId}/permissions | Update a user&#39;s permissions within an existing collection.
*CredentialsApi* | [**credentials_delete_credential**](docs/CredentialsApi.md#credentials_delete_credential) | **DELETE** /v3/credentials/{credentialId} | Delete an existing credential.
*CredentialsApi* | [**credentials_get_credential**](docs/CredentialsApi.md#credentials_get_credential) | **GET** /v3/credentials/{credentialId} | Retrieve details about an existing credential.
*CredentialsApi* | [**credentials_get_credentials**](docs/CredentialsApi.md#credentials_get_credentials) | **GET** /v3/credentials | Retrieve all accessible credential records.
*CredentialsApi* | [**credentials_remove_user_from_credential**](docs/CredentialsApi.md#credentials_remove_user_from_credential) | **DELETE** /v3/credentials/{credentialId}/users/{userId} | Remove a user&#39;s permissions to use an existing credential.
*CredentialsApi* | [**credentials_remove_user_group_from_credential**](docs/CredentialsApi.md#credentials_remove_user_group_from_credential) | **DELETE** /v3/credentials/{credentialId}/userGroups/{userGroupId} | Remove a user group&#39;s permission to use an existing credential.
*CredentialsApi* | [**credentials_share_credential_with_user**](docs/CredentialsApi.md#credentials_share_credential_with_user) | **POST** /v3/credentials/{credentialId}/users | Share an existing credential with an existing user.
*CredentialsApi* | [**credentials_share_credential_with_user_group**](docs/CredentialsApi.md#credentials_share_credential_with_user_group) | **POST** /v3/credentials/{credentialId}/userGroups | Share an existing credential with an existing user group.
*DCMEApi* | [**d_cme_delete_dcm_connection**](docs/DCMEApi.md#d_cme_delete_dcm_connection) | **DELETE** /v3/dcm/connections/{id} | Delete a DCM Connection
*DCMEApi* | [**d_cme_get_dcm_connection**](docs/DCMEApi.md#d_cme_get_dcm_connection) | **GET** /v3/dcm/connections/{id} | Retrieve a DCM Connection record
*DCMEApi* | [**d_cme_lookup_dcm_connection**](docs/DCMEApi.md#d_cme_lookup_dcm_connection) | **GET** /v3/dcm/connections/lookup | Retrieve a DCM Connection as referenced in workflows
*DCMEApi* | [**d_cme_share_dcm_connection_for_execution**](docs/DCMEApi.md#d_cme_share_dcm_connection_for_execution) | **PUT** /v3/dcm/connections/{id}/sharing/execution | Shares a DCM Connection with specified Users and Groups
*DCMEApi* | [**d_cme_unshare_dcm_connection_for_execution**](docs/DCMEApi.md#d_cme_unshare_dcm_connection_for_execution) | **DELETE** /v3/dcm/connections/{id}/sharing/execution | Unshares a DCM Connection
*DCMEApi* | [**d_cme_upsert_dcm_connection**](docs/DCMEApi.md#d_cme_upsert_dcm_connection) | **POST** /v3/dcm/connections | Create or update a DCM Connection
*DCMEAdminApi* | [**d_cme_admin_delete_connection_admin**](docs/DCMEAdminApi.md#d_cme_admin_delete_connection_admin) | **DELETE** /v3/dcm/admin/connections/{objectId} | Delete a DCM Connection
*DCMEAdminApi* | [**d_cme_admin_delete_dcme_connection_handling_rule**](docs/DCMEAdminApi.md#d_cme_admin_delete_dcme_connection_handling_rule) | **DELETE** /v3/dcm/admin/connectionhandlingrules/{id} | Deletes an existing DCM.E ConnectionHandlingRule
*DCMEAdminApi* | [**d_cme_admin_get_all_connections_admin**](docs/DCMEAdminApi.md#d_cme_admin_get_all_connections_admin) | **GET** /v3/dcm/admin/connections | Retrieve a list of DCM Connection records
*DCMEAdminApi* | [**d_cme_admin_get_all_dcme_connection_handling_rules**](docs/DCMEAdminApi.md#d_cme_admin_get_all_dcme_connection_handling_rules) | **GET** /v3/dcm/admin/connectionhandlingrules | Returns all DCME ConnectionHandlingRules
*DCMEAdminApi* | [**d_cme_admin_get_connection_admin**](docs/DCMEAdminApi.md#d_cme_admin_get_connection_admin) | **GET** /v3/dcm/admin/connections/{objectId} | Retrieve a DCM Connection record
*DCMEAdminApi* | [**d_cme_admin_get_dcme_connection_handling_rule**](docs/DCMEAdminApi.md#d_cme_admin_get_dcme_connection_handling_rule) | **GET** /v3/dcm/admin/connectionhandlingrules/{id} | Gets a DCM.E ConnectionHandlingRule
*DCMEAdminApi* | [**d_cme_admin_unshare_connection_for_collaboration_admin**](docs/DCMEAdminApi.md#d_cme_admin_unshare_connection_for_collaboration_admin) | **DELETE** /v3/dcm/admin/connections/{objectId}/sharing/collaboration | Unshares a DCM Connection shared for collaboration
*DCMEAdminApi* | [**d_cme_admin_unshare_connection_for_execution_admin**](docs/DCMEAdminApi.md#d_cme_admin_unshare_connection_for_execution_admin) | **DELETE** /v3/dcm/admin/connections/{objectId}/sharing/execution | Unshares a DCM Connection shared for execution
*DCMEAdminApi* | [**d_cme_admin_upsert_dcm_connection**](docs/DCMEAdminApi.md#d_cme_admin_upsert_dcm_connection) | **POST** /v3/dcm/admin/connections | Create or update a DCM Connection on behalf of user.
*DCMEAdminApi* | [**d_cme_admin_upsert_dcme_connection_handling_rule**](docs/DCMEAdminApi.md#d_cme_admin_upsert_dcme_connection_handling_rule) | **POST** /v3/dcm/admin/connectionhandlingrules | Adds (when id is null) or updates (when id is defined) a new DCM.E ConnectionHandlingRule
*DCMEConnectApi* | [**d_cme_connect_get_dcme_connection_for_connect**](docs/DCMEConnectApi.md#d_cme_connect_get_dcme_connection_for_connect) | **GET** /v3/DCMEConnections/{connectionId} | Retrieve details about an existing DCM connection.
*JobsApi* | [**jobs_get_job_messages**](docs/JobsApi.md#jobs_get_job_messages) | **GET** /v3/jobs/{jobId}/messages | Retrieve all messages of a specific job.
*JobsApi* | [**jobs_get_job_v3**](docs/JobsApi.md#jobs_get_job_v3) | **GET** /v3/jobs/{jobId} | Retrieve details about an existing job and its current state.
*SchedulesApi* | [**schedules_create_schedule**](docs/SchedulesApi.md#schedules_create_schedule) | **POST** /v3/schedules | Create a new schedule.
*SchedulesApi* | [**schedules_delete_schedule**](docs/SchedulesApi.md#schedules_delete_schedule) | **DELETE** /v3/schedules/{scheduleId} | Delete an existing schedule.
*SchedulesApi* | [**schedules_get_schedule**](docs/SchedulesApi.md#schedules_get_schedule) | **GET** /v3/schedules/{scheduleId} | Retrieve details about an existing schedule.
*SchedulesApi* | [**schedules_get_schedules**](docs/SchedulesApi.md#schedules_get_schedules) | **GET** /v3/schedules | Retrieve all accessible schedule records.
*SchedulesApi* | [**schedules_update_schedule**](docs/SchedulesApi.md#schedules_update_schedule) | **PUT** /v3/schedules/{scheduleId} | Update details of an existing schedule.
*SchedulesApi* | [**schedules_update_schedule_patch**](docs/SchedulesApi.md#schedules_update_schedule_patch) | **PATCH** /v3/schedules/{scheduleId} | Update details of an existing schedule.
*ServerConnectionsApi* | [**server_connections_add_user_group_to_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_add_user_group_to_server_data_connection) | **POST** /v3/serverDataConnections/{dataConnectionId}/userGroups | Share an existing Server data connection with an existing user group.
*ServerConnectionsApi* | [**server_connections_add_user_to_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_add_user_to_server_data_connection) | **POST** /v3/serverDataConnections/{dataConnectionId}/users | Share an existing Server data connection with an existing user.
*ServerConnectionsApi* | [**server_connections_delete_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_delete_server_data_connection) | **DELETE** /v3/serverDataConnections/{dataConnectionId} | Delete an existing Server data connection.
*ServerConnectionsApi* | [**server_connections_get_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_get_server_data_connection) | **GET** /v3/serverDataConnections/{dataConnectionId} | Retrieve details about an existing Server data connection.
*ServerConnectionsApi* | [**server_connections_get_server_data_connections**](docs/ServerConnectionsApi.md#server_connections_get_server_data_connections) | **GET** /v3/serverDataConnections | Retrieve all accessible Server data connection records.
*ServerConnectionsApi* | [**server_connections_remove_user_from_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_remove_user_from_server_data_connection) | **DELETE** /v3/serverDataConnections/{dataConnectionId}/users/{userId} | Remove a user&#39;s permissions to use an existing Server data connection.
*ServerConnectionsApi* | [**server_connections_remove_user_group_from_server_data_connection**](docs/ServerConnectionsApi.md#server_connections_remove_user_group_from_server_data_connection) | **DELETE** /v3/serverDataConnections/{dataConnectionId}/userGroups/{userGroupId} | Remove a user group&#39;s permissions to use an existing Server data connection.
*ServerConnectionsApi* | [**server_connections_update_server_data_connection_name**](docs/ServerConnectionsApi.md#server_connections_update_server_data_connection_name) | **PUT** /v3/serverDataConnections/{dataConnectionId} | Update the connection name of an existing Server data connection.
*SubscriptionsApi* | [**subscriptions_change_users_subscription**](docs/SubscriptionsApi.md#subscriptions_change_users_subscription) | **PUT** /v3/subscriptions/{subscriptionId}/users | Change users subscription.
*SubscriptionsApi* | [**subscriptions_create_subscription**](docs/SubscriptionsApi.md#subscriptions_create_subscription) | **POST** /v3/subscriptions | Create new subscription.
*SubscriptionsApi* | [**subscriptions_delete_subscription**](docs/SubscriptionsApi.md#subscriptions_delete_subscription) | **DELETE** /v3/subscriptions | Delete an existing subscription.
*SubscriptionsApi* | [**subscriptions_get_subscription_by_id**](docs/SubscriptionsApi.md#subscriptions_get_subscription_by_id) | **GET** /v3/subscriptions/{subscriptionId} | Retrieve details about an existing subscription.
*SubscriptionsApi* | [**subscriptions_get_subscriptions**](docs/SubscriptionsApi.md#subscriptions_get_subscriptions) | **GET** /v3/subscriptions | Retrieve details about existing subscriptions.
*SubscriptionsApi* | [**subscriptions_update_subscription**](docs/SubscriptionsApi.md#subscriptions_update_subscription) | **PUT** /v3/subscriptions/{subscriptionId} | Update an existing subscription.
*UserGroupsApi* | [**user_groups_add_active_directory_group_to_custom_group**](docs/UserGroupsApi.md#user_groups_add_active_directory_group_to_custom_group) | **POST** /v3/usergroups/{userGroupId}/activedirectorygroups | Add an Active Directory group to an existing user group.
*UserGroupsApi* | [**user_groups_add_users_to_group**](docs/UserGroupsApi.md#user_groups_add_users_to_group) | **POST** /v3/usergroups/{userGroupId}/users | Add one or more existing users to an existing user group.
*UserGroupsApi* | [**user_groups_create_user_group**](docs/UserGroupsApi.md#user_groups_create_user_group) | **POST** /v3/usergroups | Create a new user group.
*UserGroupsApi* | [**user_groups_delete_user_group**](docs/UserGroupsApi.md#user_groups_delete_user_group) | **DELETE** /v3/usergroups/{userGroupId} | Delete an existing user group.
*UserGroupsApi* | [**user_groups_get_user_group**](docs/UserGroupsApi.md#user_groups_get_user_group) | **GET** /v3/usergroups/{userGroupId} | Retrieve details about an existing user group.
*UserGroupsApi* | [**user_groups_get_user_groups**](docs/UserGroupsApi.md#user_groups_get_user_groups) | **GET** /v3/usergroups | Retrieve all accessible user group records.
*UserGroupsApi* | [**user_groups_remove_active_directory_group_from_custom_group**](docs/UserGroupsApi.md#user_groups_remove_active_directory_group_from_custom_group) | **DELETE** /v3/usergroups/{userGroupId}/activedirectorygroups/{adGroupSid} | Remove an Active Directory group from an existing user group.
*UserGroupsApi* | [**user_groups_remove_user_from_group**](docs/UserGroupsApi.md#user_groups_remove_user_from_group) | **DELETE** /v3/usergroups/{userGroupId}/users/{userId} | Remove a user from an existing user group.
*UserGroupsApi* | [**user_groups_update_user_group**](docs/UserGroupsApi.md#user_groups_update_user_group) | **PUT** /v3/usergroups/{userGroupId} | Update name and/or role of an existing user group.
*UsersApi* | [**users_create_user**](docs/UsersApi.md#users_create_user) | **POST** /v3/users | Create a new user.
*UsersApi* | [**users_deactivate_user**](docs/UsersApi.md#users_deactivate_user) | **POST** /v3/users/{userId}/deactivate | Update an existing user as inactive.
*UsersApi* | [**users_delete_user**](docs/UsersApi.md#users_delete_user) | **DELETE** /v3/users/{userId} | Delete an existing user.
*UsersApi* | [**users_get_user**](docs/UsersApi.md#users_get_user) | **GET** /v3/users/{userId} | Retrieve details about an existing user.
*UsersApi* | [**users_get_users**](docs/UsersApi.md#users_get_users) | **GET** /v3/users | Retrieve all accessible user records.
*UsersApi* | [**users_get_users_assets**](docs/UsersApi.md#users_get_users_assets) | **GET** /v3/users/{userId}/assets | Retrieve all accessible assets owned by an existing user.
*UsersApi* | [**users_send_password_reset**](docs/UsersApi.md#users_send_password_reset) | **POST** /v3/users/{userId}/passwordReset | Send a password reset email to an existing user.
*UsersApi* | [**users_transfer_assets**](docs/UsersApi.md#users_transfer_assets) | **PUT** /v3/users/{userId}/assetTransfer | Transfer all assets (workflows, schedules, collections) owned by one user to another.
*UsersApi* | [**users_update_user**](docs/UsersApi.md#users_update_user) | **PUT** /v3/users/{userId} | Update details of an existing user.
*WorkflowsApi* | [**workflows_add_version_to_workflow**](docs/WorkflowsApi.md#workflows_add_version_to_workflow) | **POST** /v3/workflows/{workflowId}/versions | Upload a new version of an existing workflow.
*WorkflowsApi* | [**workflows_create_workflow**](docs/WorkflowsApi.md#workflows_create_workflow) | **POST** /v3/workflows | Upload a new workflow package.
*WorkflowsApi* | [**workflows_delete_workflow**](docs/WorkflowsApi.md#workflows_delete_workflow) | **DELETE** /v3/workflows/{workflowId} | Delete an existing workflow.
*WorkflowsApi* | [**workflows_download_workflow**](docs/WorkflowsApi.md#workflows_download_workflow) | **GET** /v3/workflows/{workflowId}/package | Download a copy of an existing workflow package.
*WorkflowsApi* | [**workflows_enqueue**](docs/WorkflowsApi.md#workflows_enqueue) | **POST** /v3/workflows/{workflowId}/jobs | Creates a new job and adds it to the job execution queue.
*WorkflowsApi* | [**workflows_get_jobs_for_workflow**](docs/WorkflowsApi.md#workflows_get_jobs_for_workflow) | **GET** /v3/workflows/{workflowId}/jobs | Retrieve a list of jobs for an existing workflow.
*WorkflowsApi* | [**workflows_get_workflow**](docs/WorkflowsApi.md#workflows_get_workflow) | **GET** /v3/workflows/{workflowId} | Retrieve details about an existing workflow.
*WorkflowsApi* | [**workflows_get_workflow_questions**](docs/WorkflowsApi.md#workflows_get_workflow_questions) | **GET** /v3/workflows/{workflowId}/questions | Retrieve question information for an analytic app.
*WorkflowsApi* | [**workflows_get_workflows**](docs/WorkflowsApi.md#workflows_get_workflows) | **GET** /v3/workflows | Retrieve all accessible workflow records.
*WorkflowsApi* | [**workflows_transfer_workflow**](docs/WorkflowsApi.md#workflows_transfer_workflow) | **PUT** /v3/workflows/{workflowId}/transfer | Transfer specified workflow to specified owner and also schedules if desired
*WorkflowsApi* | [**workflows_update_workflow**](docs/WorkflowsApi.md#workflows_update_workflow) | **PUT** /v3/workflows/{workflowId} | Update details of an existing workflow.


## Documentation For Models

 - [ADObject](docs/ADObject.md)
 - [ActiveDirectoryObjectView](docs/ActiveDirectoryObjectView.md)
 - [AddCredentialsUserContract](docs/AddCredentialsUserContract.md)
 - [AddCredentialsUserGroupContract](docs/AddCredentialsUserGroupContract.md)
 - [AddScheduleContract](docs/AddScheduleContract.md)
 - [AddServerConnectionUserContract](docs/AddServerConnectionUserContract.md)
 - [AddServerConnectionUserGroupContract](docs/AddServerConnectionUserGroupContract.md)
 - [AddUserContract](docs/AddUserContract.md)
 - [AddUserGroupContract](docs/AddUserGroupContract.md)
 - [AddWorkflowContract](docs/AddWorkflowContract.md)
 - [AffectedScheduleView](docs/AffectedScheduleView.md)
 - [AppValue](docs/AppValue.md)
 - [AssetDataView](docs/AssetDataView.md)
 - [AssetsView](docs/AssetsView.md)
 - [ChangeUsersSubscriptionContract](docs/ChangeUsersSubscriptionContract.md)
 - [CollectionUserView](docs/CollectionUserView.md)
 - [CollectionView](docs/CollectionView.md)
 - [CollectionsPermissionsViewContract](docs/CollectionsPermissionsViewContract.md)
 - [CreateCollectionContract](docs/CreateCollectionContract.md)
 - [CreateScheduleContract](docs/CreateScheduleContract.md)
 - [CreateSubscriptionContract](docs/CreateSubscriptionContract.md)
 - [CreateUserContract](docs/CreateUserContract.md)
 - [CreateUserGroupContract](docs/CreateUserGroupContract.md)
 - [CredentialsView](docs/CredentialsView.md)
 - [DCMEConnectionHandlingRuleContract](docs/DCMEConnectionHandlingRuleContract.md)
 - [DCMECredentialContract](docs/DCMECredentialContract.md)
 - [DCMECredentialView](docs/DCMECredentialView.md)
 - [DCMEDataSourceContract](docs/DCMEDataSourceContract.md)
 - [DCMEDataSourceForConnectView](docs/DCMEDataSourceForConnectView.md)
 - [DCMEDataSourceView](docs/DCMEDataSourceView.md)
 - [DCMEDeleteConnectionView](docs/DCMEDeleteConnectionView.md)
 - [DCMEGetConnectionForConnectView](docs/DCMEGetConnectionForConnectView.md)
 - [DCMEGetConnectionView](docs/DCMEGetConnectionView.md)
 - [DCMEObjectWrapperContractDCMECredentialContract](docs/DCMEObjectWrapperContractDCMECredentialContract.md)
 - [DCMEObjectWrapperContractDCMEDataSourceContract](docs/DCMEObjectWrapperContractDCMEDataSourceContract.md)
 - [DCMESecretContract](docs/DCMESecretContract.md)
 - [DCMESecretValueContract](docs/DCMESecretValueContract.md)
 - [DCMESecretView](docs/DCMESecretView.md)
 - [DCMEShareForCollaborationContract](docs/DCMEShareForCollaborationContract.md)
 - [DCMEShareForExecutionContract](docs/DCMEShareForExecutionContract.md)
 - [DCMESharingForCollaborationView](docs/DCMESharingForCollaborationView.md)
 - [DCMESharingForExecutionView](docs/DCMESharingForExecutionView.md)
 - [DCMESharingView](docs/DCMESharingView.md)
 - [DCMEUpsertConnectionAdminContract](docs/DCMEUpsertConnectionAdminContract.md)
 - [DCMEUpsertConnectionContract](docs/DCMEUpsertConnectionContract.md)
 - [DCMEUserGroupView](docs/DCMEUserGroupView.md)
 - [DCMEUserView](docs/DCMEUserView.md)
 - [DeletedConnectionView](docs/DeletedConnectionView.md)
 - [DeletedCredentialView](docs/DeletedCredentialView.md)
 - [DeletedDataSourceView](docs/DeletedDataSourceView.md)
 - [EnqueueJobContract](docs/EnqueueJobContract.md)
 - [InvalidRequestResponseBody](docs/InvalidRequestResponseBody.md)
 - [IterationBase](docs/IterationBase.md)
 - [IterationContract](docs/IterationContract.md)
 - [IterationCustomContract](docs/IterationCustomContract.md)
 - [IterationDailyContract](docs/IterationDailyContract.md)
 - [IterationHourlyContract](docs/IterationHourlyContract.md)
 - [IterationMonthlyContract](docs/IterationMonthlyContract.md)
 - [IterationWeeklyContract](docs/IterationWeeklyContract.md)
 - [JobMessageView](docs/JobMessageView.md)
 - [JobView](docs/JobView.md)
 - [Member](docs/Member.md)
 - [MessageView](docs/MessageView.md)
 - [OutputDataView](docs/OutputDataView.md)
 - [PatchScheduleContract](docs/PatchScheduleContract.md)
 - [ReducedCollectionView](docs/ReducedCollectionView.md)
 - [ReducedCredentialsView](docs/ReducedCredentialsView.md)
 - [ReducedScheduleView](docs/ReducedScheduleView.md)
 - [ReducedServerConnectionView](docs/ReducedServerConnectionView.md)
 - [ReducedUserGroupView](docs/ReducedUserGroupView.md)
 - [ReducedUserView](docs/ReducedUserView.md)
 - [ReducedWorkflowView](docs/ReducedWorkflowView.md)
 - [ScheduleView](docs/ScheduleView.md)
 - [SearchSubscriptionContract](docs/SearchSubscriptionContract.md)
 - [SearchUserContract](docs/SearchUserContract.md)
 - [ServerConnectionView](docs/ServerConnectionView.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionCredential](docs/SubscriptionCredential.md)
 - [SubscriptionDataConnection](docs/SubscriptionDataConnection.md)
 - [SubscriptionUserWorkflowCountView](docs/SubscriptionUserWorkflowCountView.md)
 - [SubscriptionUserWorkflowDetailsView](docs/SubscriptionUserWorkflowDetailsView.md)
 - [SubscriptionView](docs/SubscriptionView.md)
 - [TransferUserAssetsContract](docs/TransferUserAssetsContract.md)
 - [TransferWorkflowContract](docs/TransferWorkflowContract.md)
 - [UpdateCollectionContract](docs/UpdateCollectionContract.md)
 - [UpdatePermissionsContract](docs/UpdatePermissionsContract.md)
 - [UpdateScheduleContract](docs/UpdateScheduleContract.md)
 - [UpdateServerConnectionContract](docs/UpdateServerConnectionContract.md)
 - [UpdateSubscriptionContract](docs/UpdateSubscriptionContract.md)
 - [UpdateUserContract](docs/UpdateUserContract.md)
 - [UpdateUserGroupContract](docs/UpdateUserGroupContract.md)
 - [UpdateWorkflowContract](docs/UpdateWorkflowContract.md)
 - [UserGroupAddedUsersView](docs/UserGroupAddedUsersView.md)
 - [UserGroupView](docs/UserGroupView.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserView](docs/UserView.md)
 - [WorkflowDetails](docs/WorkflowDetails.md)
 - [WorkflowInfo](docs/WorkflowInfo.md)
 - [WorkflowJobView](docs/WorkflowJobView.md)
 - [WorkflowQuestionItemView](docs/WorkflowQuestionItemView.md)
 - [WorkflowQuestionView](docs/WorkflowQuestionView.md)
 - [WorkflowVersionView](docs/WorkflowVersionView.md)
 - [WorkflowView](docs/WorkflowView.md)


## Documentation For Authorization


## oauth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Author



